### A simple ai tools repository

This repository contains a collection of simple ai tools that I have created or collected. 

### Implemented models

1. [Self-Attentive Associative Memory | SAM](https://arxiv.org/abs/2002.03519)

### Use method

You can run `train` method from corresponded `main.py` file. Such as:
    
```python
# take sam as example
# just two line required to run the train task.
from noobai.model.sam.main import train
train()
```